diff --git a/CHANGELOG b/CHANGELOG
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -1,3 +1,7 @@
+# 0.6.0.0
+
+- Update to match change in foldl library.
+
 # 0.5.1.0
 
 - Removed upper bounds in dependencies.
diff --git a/foldl-transduce.cabal b/foldl-transduce.cabal
--- a/foldl-transduce.cabal
+++ b/foldl-transduce.cabal
@@ -1,5 +1,5 @@
 Name: foldl-transduce
-Version: 0.5.2.0
+Version: 0.6.0.0
 Cabal-Version: >=1.8.0.2
 Build-Type: Simple
 License: BSD3
@@ -32,7 +32,7 @@
         profunctors   >= 5                 ,
         semigroups    >= 0.18              ,
         semigroupoids >= 5.0               ,
-        foldl         >= 1.1.5             ,
+        foldl         >= 1.4               ,
         comonad       >= 4                 ,
         free          >= 4                 ,         
         void          >= 0.6               ,
diff --git a/src/Control/Foldl/Transduce.hs b/src/Control/Foldl/Transduce.hs
--- a/src/Control/Foldl/Transduce.hs
+++ b/src/Control/Foldl/Transduce.hs
@@ -607,7 +607,7 @@
 
 instance (Functor m, Monad m) => Profunctor (Fallible m r) where
     lmap f (Fallible fallible) = 
-        Fallible (L.premapM f fallible)
+        Fallible (L.premapM (return . f) fallible)
 
     rmap g (Fallible fallible) = 
         Fallible (hoistFold (withExceptT g) fallible)
diff --git a/src/Control/Foldl/Transduce/Text.hs b/src/Control/Foldl/Transduce/Text.hs
--- a/src/Control/Foldl/Transduce/Text.hs
+++ b/src/Control/Foldl/Transduce/Text.hs
@@ -102,7 +102,7 @@
 ["across ","\9731 boundaries"]
 
 >>> L.fold (transduce utf8lenient L.list) (map fromString ["invalid \xc3\x28 sequence"])
-["invalid \65533 sequence"]
+["invalid \65533( sequence"]
 
 >>> L.fold (transduce utf8lenient L.list) (map fromString ["incomplete \xe2"])
 ["incomplete ","\65533"]
@@ -115,7 +115,7 @@
     __/BEWARE!/__ 
 
 >>> L.fold (transduce utf8strict L.list) (map fromString ["invalid \xc3\x28 sequence"])
 *** Exception: Cannot decode byte '\x28': Data.Text.Internal.Encoding.streamDecodeUtf8With: Invalid UTF-8 stream
 
 >>> L.fold (transduce utf8strict L.list) (map fromString ["incomplete \xe2"])
 *** Exception: Cannot decode input: leftovers
@@ -156,7 +156,7 @@
     'Control.Monad.Trans.Except' to communicate the error.        
 
 >>> runExceptT $ L.foldM (transduceM utf8E (L.generalize L.list)) (map fromString ["invalid \xc3\x28 sequence"])
-Left Cannot decode byte '\x28': Data.Text.Internal.Encoding.streamDecodeUtf8With: Invalid UTF-8 stream
+Left Cannot decode byte '\xc3': Data.Text.Internal.Encoding.streamDecodeUtf8With: Invalid UTF-8 stream
 
 >>> runExceptT $ L.foldM (transduceM utf8E (L.generalize L.list)) (map fromString ["incomplete \xe2"])
 Left Cannot decode input: leftovers
@@ -115,7 +115,7 @@
 
 >>> L.fold (transduce utf8strict L.list) (map fromString ["invalid \xc3\x28 sequence"])
-*** Exception: Cannot decode byte '\x28': Data.Text.Internal.Encoding.streamDecodeUtf8With: Invalid UTF-8 stream
+*** Exception: Cannot decode byte '\xc3': Data.Text.Internal.Encoding.streamDecodeUtf8With: Invalid UTF-8 stream
 
 >>> L.fold (transduce utf8strict L.list) (map fromString ["incomplete \xe2"])
